// ---------------------------------
// Filename      : RTCDS130x.h
// Author        : Sven Maerivoet
// Last modified : 10/11/2018
// Target        : C++ (Arduino UNO)
//
// All rights reserved.
// ---------------------------------

/*
  Copyright 2017, 2018 Sven Maerivoet

  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

   http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
*/

#ifndef RTCDS130X_h
#define RTCDS130X_h

// imports for DS1302
#include <DS1302RTC.h>
#include <TimeLib.h>
#include <Time.h>

// imports for DS1307
#include <Wire.h>
#include <RTClib.h>

class DateTimeContainer
{
	public:
		int fYear;
		int fMonth;
		int fDay;
		int fHour;
		int fMinute;
		int fSecond;
    void print();
};

class RTCDS130x
{
  public:
    enum ERTCType {kDS1302, kDS1307}; // kDS1302 = Velleman / kDS1307 = original

    // constructor
    RTCDS130x(ERTCType rtcType);

    // public methods
		void setDS1302Pins(int clkPin, int datPin, int rstPin);
    void initialise();
    DateTimeContainer getDateTime();
    void setDS1307ToNow(float compilationAndUploadTimeSec);

  private:
    // internal datastructures
    ERTCType fRTCType;
    boolean fInitialised;
    int fCLKPin;
    int fIOkPin;
    int fCEPin;
    boolean fPinsSpecified;
    DS1302RTC* fRTCDS1302;
    RTC_DS1307* fRTCDS1307;

    // private methods
    void assertInitialised();
    void fatalError(String message);
};

#endif
